package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnAnswer;

/**
 * 答卷答案Service接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface ILearnAnswerService 
{
    /**
     * 查询答卷答案
     * 
     * @param answerId 答卷答案主键
     * @return 答卷答案
     */
    public LearnAnswer selectLearnAnswerByAnswerId(Long answerId);

    /**
     * 查询答卷答案列表
     * 
     * @param learnAnswer 答卷答案
     * @return 答卷答案集合
     */
    public List<LearnAnswer> selectLearnAnswerList(LearnAnswer learnAnswer);

    /**
     * 新增答卷答案
     * 
     * @param learnAnswer 答卷答案
     * @return 结果
     */
    public int insertLearnAnswer(LearnAnswer learnAnswer);

    /**
     * 修改答卷答案
     * 
     * @param learnAnswer 答卷答案
     * @return 结果
     */
    public int updateLearnAnswer(LearnAnswer learnAnswer);

    /**
     * 批量删除答卷答案
     * 
     * @param answerIds 需要删除的答卷答案主键集合
     * @return 结果
     */
    public int deleteLearnAnswerByAnswerIds(Long[] answerIds);

    /**
     * 删除答卷答案信息
     * 
     * @param answerId 答卷答案主键
     * @return 结果
     */
    public int deleteLearnAnswerByAnswerId(Long answerId);
}
